==> atomium-7.x-1.1.tar.gz: atomium/atomium_foundation/templates/form_element/form-element.tpl.php <==
<?php

/**
 * @file
 * Form_element.tpl.php.
 */
?>
<div<?php print $attributes; ?>>

  <?php if ('before' == $element['#title_display'] || 'invisible' == $element['#title_display']): ?>

    <?php print render($label); ?>

    <?php if ($element['#field_prefix']): ?>
      <span class="field-prefix"><?php render($element['#field_prefix']); ?></span>
    <?php endif; ?>

    <?php print $element['#children']; ?>

    <?php if ($element['#field_suffix']): ?>
      <span class="field-suffix"><?php render($element['#field_suffix']); ?></span>
    <?php endif; ?>
  <?php endif; ?>

  <?php if ('after' == $element['#title_display']): ?>
    <?php if ($element['#field_prefix']): ?>
      <span class="field-prefix"><?php render($element['#field_prefix']); ?></span>
    <?php endif; ?>
      <?php print $element['#children']; ?>
    <?php if ($element['#field_suffix']): ?>
      <span class="field-suffix"><?php render($element['#field_suffix']); ?></span>
    <?php endif; ?>
    <?php print render($label); ?>
  <?php endif; ?>

  <?php if ('none' == $element['#title_display'] || 'attribute' == $element['#title_display']): ?>
    <?php if ($element['#field_prefix']): ?>
      <span class="field-prefix"><?php render($element['#field_prefix']); ?></span>
    <?php endif; ?>
      <?php print $element['#children']; ?>
    <?php if ($element['#field_suffix']): ?>
      <span class="field-suffix"><?php render($element['#field_suffix']); ?></span>
    <?php endif; ?>
  <?php endif; ?>

  <?php if (!empty($description)): ?>
    <div class="help-text"><?php print render($description); ?></div>
  <?php endif; ?>
</div>

==> atomium-7.x-2.3.tar.gz: atomium/atomium_foundation/templates/form_element/form-element.tpl.php <==
<?php

/**
 * @file
 * Form_element.tpl.php.
 */
?>
<div<?php print $atomium['attributes']['wrapper']; ?>>

  <?php if ('before' == $element['#title_display'] || 'invisible' == $element['#title_display']): ?>

    <?php print render($label); ?>

    <?php if ($element['#field_prefix']): ?>
      <span class="field-prefix"><?php render($element['#field_prefix']); ?></span>
    <?php endif; ?>

    <?php print $element['#children']; ?>

    <?php if ($element['#field_suffix']): ?>
      <span class="field-suffix"><?php render($element['#field_suffix']); ?></span>
    <?php endif; ?>
  <?php endif; ?>

  <?php if ('after' == $element['#title_display']): ?>
    <?php if ($element['#field_prefix']): ?>
      <span class="field-prefix"><?php render($element['#field_prefix']); ?></span>
    <?php endif; ?>
      <?php print $element['#children']; ?>
    <?php if ($element['#field_suffix']): ?>
      <span class="field-suffix"><?php render($element['#field_suffix']); ?></span>
    <?php endif; ?>
    <?php print render($label); ?>
  <?php endif; ?>

  <?php if ('none' == $element['#title_display'] || 'attribute' == $element['#title_display']): ?>
    <?php if ($element['#field_prefix']): ?>
      <span class="field-prefix"><?php render($element['#field_prefix']); ?></span>
    <?php endif; ?>
      <?php print $element['#children']; ?>
    <?php if ($element['#field_suffix']): ?>
      <span class="field-suffix"><?php render($element['#field_suffix']); ?></span>
    <?php endif; ?>
  <?php endif; ?>

  <?php if (!empty($description)): ?>
    <div class="help-text"><?php print render($description); ?></div>
  <?php endif; ?>
</div>
